@@ -20,6 +20,8 @@
 
 /* Default configuration file */
 #define CONFIG_FILE "./aide.conf" 
+#define DEFAULT_DB "./aide.db"
+#define DEFAULT_DB_OUT "./aide.db.new"
 
 #undef HAVE_BYTE_TYPEDEF
 #undef HAVE_USHORT_TYPEDEF
