@@ -19,7 +19,7 @@
 #ifndef _AIDE_H_INCLUDED
 #define _AIDE_H_INCLUDED
 
-#include "error.h"
+#include "report.h"
 #include "db_config.h"
 #include "config.h"
 
