@@ -20,7 +20,8 @@
 #ifndef _COMPARE_DB_H_INCLUDED
 #define _COMPARE_DB_H_INCLUDED
 #include "list.h"
+#include "db_config.h"
 
-void compare_db(list*);
+void compare_db(list*,db_config*);
 
 #endif
