@@ -17,11 +17,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef _CONF_LEX_H_INCLUDED_
+#ifndef _CONF_LEX_H_INCLUDED_
 #define _CONF_LEX_H_INCLUDED_
 
 void conf_put_token(const char* s);
 
 extern int conferror(const char*);
 
+extern int conflex();
+
 #endif
