@@ -23,14 +23,14 @@
 #include <stdio.h>
 #include "db_config.h"
 
-int db_init(int);
+int db_init(db_config*,int);
 
 db_line* db_readline(db_config*);
 
-int db_writespec();
+int db_writespec(db_config*);
 
 int db_writeline(db_line*,db_config*);
 
-int db_close(void);
+int db_close(db_config*);
 
 #endif
