@@ -123,6 +123,9 @@ typedef struct db_config {
   /* Should we catch errors from mmapping */
   int catch_mmap;
 
+  time_t start_time;
+  time_t end_time;
+
 } db_config;
 
 typedef struct db_line {
