@@ -25,7 +25,7 @@
 extern long db_lineno;
 
 char** db_readline_file(db_config*);
-int db_writespec_file();
+int db_writespec_file(db_config*);
 int db_writeline_file(db_line* line,db_config* conf);
 
 #endif
