@@ -2,7 +2,7 @@
  *
  * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
  * 
- * $Header: /cvs-root-aide/aide/include/do_md.h,v 1.3 1999/07/28 10:17:25 rammer Exp $
+ * $Header: /cvs-root-aide/aide/include/do_md.h,v 1.5 1999/10/18 14:18:02 rammer Exp $
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -20,12 +20,16 @@
  
 #ifndef _DO_MD_H_INCLUDED
 #define _DO_MD_H_INCLUDED
-#include "cipher.h"
+#ifdef WITH_MHASH
+#include "mhash.h"
+#endif
+
 #include "list.h"
+#include "db_config.h"
 
 #define BUFSIZE 16384
 
-list* do_md(list* file_lst);
+list* do_md(list* file_lst,db_config* conf);
 
 
 #endif /* _DO_MD_H_INCLUDED */
