@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999 Rami Lehti,Pablo Virolainen
- * $Header: /cvs-root-aide/aide/include/list.h,v 1.6 1999/07/28 13:40:50 rammer Exp $
+ * $Header: /cvs-root-aide/aide/include/list.h,v 1.7 1999/11/25 09:25:25 pablo Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,17 +24,33 @@
 typedef struct list {
   struct list* next;
   struct list* prev;
+
+  struct list_header* header;
+
+  /*
   struct list* head;
   struct list* tail;
+  */
+
   void* data;
 } list;
 
+typedef struct list_header{
+  
+  struct list* head;
+  struct list* tail;
+  
+}list_header;
 
 
 list* list_append(list* listp,void*data);
 
+/*
+
 list* new_list_item(void*);
 
+*/
+
 list* list_delete_item(list* item);
 
 #endif /* _DB_LIST_H_INCLUDED */
