@@ -20,6 +20,7 @@
 #ifndef _UTIL_H_INCLUDED
 #define _UTIL_H_INCLUDED
 #include <string.h>
+#include <sys/types.h>
 #include "db_config.h"
 
 #define HEXD2ASC(x) (((x) < 10) ? ((x) + '0') : ((x) - 10 + 'A'))
@@ -42,5 +43,8 @@ void decode_string(char*);
 
 char* encode_string(const char*);
 
+char* perm_to_char(mode_t perm);
+
+void sig_handler(int signal);
 
 #endif
