@@ -21,6 +21,8 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <signal.h>
+#include <sys/types.h>
+#include <time.h>
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -39,7 +41,7 @@
 #include "db_config.h"
 #include "db_file.h"
 #include "do_md.h"
-#include "error.h"
+#include "report.h"
 #include "gen_list.h"
 #include "getopt.h"
 #include "list.h"
@@ -250,6 +252,9 @@ void setdefaults_before_config()
 
   conf->defsyms=NULL;
   conf->groupsyms=NULL;
+
+  conf->start_time=time(&(conf->start_time));
+
   
   do_groupdef("p",DB_PERM);
   do_groupdef("i",DB_INODE);
@@ -293,14 +298,14 @@ void setdefaults_after_config()
     url_t* u=NULL;
     u=(url_t*)malloc(sizeof(url_t));
     u->type=url_file;
-    u->value="/etc/aide.db";
+    u->value=DEFAULT_DB;
     conf->db_in_url=u;
   }
   if(conf->db_out_url==NULL){
     url_t* u=NULL;
     u=(url_t*)malloc(sizeof(url_t));
     u->type=url_file;
-    u->value="/etc/aide.db.new";
+    u->value=DEFAULT_DB_OUT;
     conf->db_out_url=u;
   }
   if(conf->report_url==NULL){
