@@ -34,7 +34,7 @@
 #include <stdlib.h>
 #include "config.h"
 #include "base64.h"
-#include "error.h"
+#include "report.h"
 
 char tob64[] = 
 "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
