@@ -86,11 +86,18 @@ int commandconf(const char mode,const char* line)
   case 'D': {
     /* Let's do it */
     int rv=-1;
-   
-    rv=access(config,R_OK);
-    if(rv==-1){
-      error(0,"Cannot access config file:%s:%s\n",config,strerror(errno));
+    
+    if (config!=NULL && strcmp(config,"-")==0) {
+      error(255,"Config from stdin\n");
+      rv=0;
+    } else {
+      
+      rv=access(config,R_OK);
+      if(rv==-1){
+	error(0,"Cannot access config file:%s:%s\n",config,strerror(errno));
+      }
     }
+    
     if(before==NULL&&after==NULL&&
        (config==NULL||strcmp(config,"")==0||rv==-1)){
       error(0,"No config defined\n");
@@ -200,6 +207,26 @@ void update_db_out_order(int a)
   if((a&DB_TIGER) && (check_dboo(db_tiger)!=RETFAIL)){
     conf->db_out_order[conf->db_out_size++]=db_tiger;
   }
+#ifdef WITH_MHASH
+  if((a&DB_CRC32) && (check_dboo(db_crc32)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_crc32;
+  }
+  if((a&DB_HAVAL) && (check_dboo(db_haval)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_haval;
+  }
+  if((a&DB_RMD128) && (check_dboo(db_rmd128)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_rmd128;
+  }
+  if((a&DB_SNEFRU) && (check_dboo(db_snefru)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_snefru;
+  }
+  if((a&DB_GOST) && (check_dboo(db_gost)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_gost;
+  }
+  if((a&DB_CRC32B) && (check_dboo(db_crc32b)!=RETFAIL)){
+    conf->db_out_order[conf->db_out_size++]=db_crc32b;
+  }
+#endif
 }
 
 
