@@ -19,11 +19,14 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <sys/stat.h>
 #include "base64.h"
-#include "error.h"
+#include "report.h"
 #include "db_config.h"
 #include "aide.h"
+#include "gnu_regex.h"
+#include "gen_list.h"
 #include "list.h"
 #include "db.h"
 #include "util.h"
@@ -214,7 +217,6 @@ int compare_lines(db_line* l1,db_line* l2,int ignorelist)
     }
   }
 
-  /* FIXME Add the rest of mhash algos */  
 #endif
   
   return RETOK;
@@ -249,16 +251,39 @@ void print_md_changes(byte*old,byte*new,int len,char* fnam)
   }
 }
 
+void print_time_changes(const char* name, time_t old_time, time_t new_time)
+{
+  struct tm otm;
+  struct tm *ot = &otm;
+  struct tm *tmp = localtime(&old_time);
+  struct tm *nt;
+  
+  /* lib stores last tm call in static storage */
+  ot->tm_year = tmp->tm_year; ot->tm_mon = tmp->tm_mon;
+  ot->tm_mday = tmp->tm_mday;  ot->tm_hour = tmp->tm_hour;
+  ot->tm_min = tmp->tm_min; ot->tm_sec = tmp->tm_sec;
+  
+  nt = localtime(&(new_time));
+  
+  error(5,"%s: old = %0.4u-%0.2u-%0.2u %0.2u:%0.2u:%0.2u,"
+	" new = %0.4u-%0.2u-%0.2u %0.2u:%0.2u:%0.2u\n", name,
+           ot->tm_year+1900, ot->tm_mon+1, ot->tm_mday,
+	ot->tm_hour, ot->tm_min, ot->tm_sec,
+	nt->tm_year+1900, nt->tm_mon+1, nt->tm_mday,
+	nt->tm_hour, nt->tm_min, nt->tm_sec);
+}
+
+
 void print_dbline_changes(db_line* old,db_line* new,int ignorelist)
 {
   char* tmp=NULL;
   char* tmp2=NULL;
 
-  error(5,"\nfile: %s\n",old->filename);
+  error(5,"\nFile: %s\n",old->filename);
 
   if (!(DB_SIZE&ignorelist)) {
     if(old->size!=new->size){
-      error(5,"Size: old = %i , new = %i\n",
+      error(5,"Size: old = %u , new = %u\n",
 	    old->size,new->size);
     }
   }
@@ -298,22 +323,19 @@ void print_dbline_changes(db_line* old,db_line* new,int ignorelist)
   
   if (!(DB_ATIME&ignorelist)) {
     if(old->atime!=new->atime){
-      error(5,"Atime: old = %i , new = %i\n",
-	    old->atime,new->atime);
+      print_time_changes("Atime", old->atime, new->atime);
     }
   }
   
   if (!(DB_MTIME&ignorelist)) {
     if(old->mtime!=new->mtime){
-      error(5,"Mtime: old = %i , new = %i\n",
-	    old->mtime,new->mtime);
+      print_time_changes("Mtime", old->mtime, new->mtime);
     }
   }
   
   if (!(DB_CTIME&ignorelist)) {
     if(old->ctime!=new->ctime){
-      error(5,"Ctime: old = %i , new = %i\n",
-	    old->ctime,new->ctime);
+      print_time_changes("Ctime", old->ctime, new->ctime);
     }
   }
 
@@ -427,15 +449,56 @@ void free_db_line(db_line* dl)
 
 }
 
+void init_rxlst(list* rxlst)
+{
+  list* r=NULL;
+  rx_rule* rxrultmp=NULL;
+  regex_t* rxtmp=NULL;
+
+
+  for(r=rxlst;r;r=r->next){
+    char* data=NULL;
+    /* We have to add '^' to the first charaster of string... 
+     *
+     */
+    
+    data=(char*)malloc(strlen(((rx_rule*)r->data)->rx)+1+1);
+    
+    if (data==NULL){
+      error(0,"Not enough memory for regexpr compile... exiting..\n");
+      abort();
+    }
+    
+    strcpy(data+1,((rx_rule*)r->data)->rx);
+    
+    data[0]='^';
+    
+    rxrultmp=((rx_rule*)r->data);
+    rxtmp=(regex_t*)malloc(sizeof(regex_t));
+    if( regcomp(rxtmp,data,REG_EXTENDED|REG_NOSUB)){
+      error(0,"Error in selective regexp:%s",((rx_rule*)r->data)->rx);
+      free(data);
+    }else {
+      free(rxrultmp->rx);
+      rxrultmp->rx=data;
+      rxrultmp->crx=rxtmp;
+    }
+    
+  }
+
+}
+
 list* eat_files_indir(list* flist,char* dirname,long* filcount)
 {
   list* r=NULL;
-  list* last=NULL;
+  list* last=flist;
 
   *filcount=0;
 
   for(r=flist;r;r=r->next){
-    if(strncmp(dirname,((db_line*)r->data)->filename,strlen(dirname)-1)==0){
+    if((strlen(((db_line*)r->data)->filename)>=strlen(dirname)) && 
+       (strncmp(dirname,((db_line*)r->data)->filename,strlen(dirname)-1)==0)
+       && ((((db_line*)r->data)->filename)[strlen(dirname)]=='/')){
       free_db_line((db_line*)r->data);
       free(r->data);
       r=list_delete_item(r);
@@ -461,19 +524,49 @@ void compare_db(list* new,db_config* conf)
   long nadd=0;
   long nfil=0;
   long filesindir=0;
+  int tempignore=0;
+  int initdbwarningprinted=0;
+
+  int ignorelist;
+
+  error(200,"compare_db()\n");
+
+
+  /* With this we avoid unnecessary checking of removed files. */
+  if(conf->action&DO_INIT){
+    initdbwarningprinted=1;
+  } else {
+    /* We have to init the rxlsts since they are copied and then 
+       initialized in gen_list.c */
+    init_rxlst(conf->selrxlst);
+    init_rxlst(conf->equrxlst);
+    init_rxlst(conf->negrxlst);
+  }
   
-  int ignorelist=get_groupval("ignore_list");
+  /* We have a way to ignore some changes... */ 
+  
+  ignorelist=get_groupval("ignore_list");
   
   if (ignorelist==-1) {
     ignorelist=0;
   }
-  
-  error(200,"compare_db()\n");
 
   for(old=db_readline(conf);old;old=db_readline(conf)){
     nfil++;
     r=find_line_match(old,l);
     if(r==NULL){
+      /* The WARNING is only printed once */
+      /* FIXME There should be a check for this in changed part also */
+      /* This part should also be rethinked */
+      if(!initdbwarningprinted &&
+	 (!check_list_for_match(conf->selrxlst,old->filename,&tempignore) ||
+	  !check_list_for_match(conf->equrxlst,old->filename,&tempignore)) &&
+	 check_list_for_match(conf->negrxlst,old->filename,&tempignore)){
+	if(!(conf->action&DO_INIT)){
+	  error(5,"WARNING: Old db contains a file that shouldn\'t be there, run --init or --update\n");
+	}
+	initdbwarningprinted=1;
+      }
       removed=list_append(removed,(void*)old);
       nrem++;
     }else {
@@ -508,6 +601,12 @@ void compare_db(list* new,db_config* conf)
 
 
   if(nadd!=0||nrem!=0||nchg!=0){
+    struct tm* st=localtime(&(conf->start_time));
+    
+    error(0,"AIDE found differences between database and filesystem!!\n");
+    error(5,"Start timestamp: %0.4u-%0.2u-%0.2u %0.2u:%0.2u:%0.2u\n",
+	  st->tm_year+1900, st->tm_mon+1, st->tm_mday,
+	  st->tm_hour, st->tm_min, st->tm_sec);
     error(0,"Summary:\nTotal number of files=%i,added files=%i"
 	  ",removed files=%i,changed files=%i\n\n",nfil,nadd,nrem,nchg);
 
@@ -517,6 +616,9 @@ void compare_db(list* new,db_config* conf)
 	error(5,"added:%s\n",((db_line*)r->data)->filename);
 	if(conf->verbose_level<20){
 	  if(S_ISDIR(((db_line*)r->data)->perm)){
+	    /*	    free_db_line((db_line*)r->data);
+	    free(r->data);
+	    r=list_delete_item(r);*/
 	    r=eat_files_indir(r,((db_line*)r->data)->filename,&filesindir);
 	    if(filesindir>0){
 	      error(5,
@@ -547,8 +649,14 @@ void compare_db(list* new,db_config* conf)
     if((conf->verbose_level>=5)&&(nchg!=0)){
       error(5,"Detailed information about changes:\n");
       for(r=changedold,l=changednew;r;r=r->next,l=l->next){
-	print_dbline_changes((db_line*)r->data,(db_line*)l->data,ignorelist);
+	print_dbline_changes((db_line*)r->data,
+			     (db_line*)l->data,ignorelist);
       }
     }
+    conf->end_time=time(&(conf->end_time));
+    st=localtime(&(conf->end_time));
+    error(20,"\nEnd timestamp: %0.4u-%0.2u-%0.2u %0.2u:%0.2u:%0.2u\n",
+	  st->tm_year+1900, st->tm_mon+1, st->tm_mday,
+	  st->tm_hour, st->tm_min, st->tm_sec);
   }
 }
