@@ -24,7 +24,7 @@
 #include "db.h"
 #include "db_file.h"
 #include "db_config.h"
-#include "error.h"
+#include "report.h"
 #include "be.h"
 
 #ifdef WITH_MHASH
@@ -206,6 +206,38 @@ db_line* db_char2line(char** ss,db_config* conf){
 			       strlen(ss[conf->db_in_order[i]]));
       break;
     }
+#ifdef WITH_MHASH
+    case db_crc32 : {
+      line->crc32=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+    case db_gost : {
+      line->gost=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+    case db_haval : {
+      line->haval=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+    case db_rmd128 : {
+      line->rmd128=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+    case db_snefru : {
+      line->snefru=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+    case db_crc32b : {
+      line->crc32b=base64tobyte(ss[conf->db_in_order[i]],
+			       strlen(ss[conf->db_in_order[i]]));
+      break;
+    }
+#endif
     case db_perm : {
       line->perm=readoct(ss[conf->db_in_order[i]],"permissions");
       break;
