@@ -29,7 +29,7 @@
 
 #include "db_config.h"
 #include "do_md.h"
-#include "error.h"
+#include "report.h"
 #include "list.h"
 
 /* This define should be somewhere else */
@@ -131,7 +131,7 @@ list* do_md(list* file_lst,db_config* conf)
 	 || dl->crc32 || dl->haval || dl->rmd128 || dl->snefru || 
 	 dl->gost || dl->crc32b 
 #endif
-))
+	 ))
       continue;
     /* Lets reset... */
 #ifdef WITH_MHASH
@@ -177,9 +177,7 @@ list* do_md(list* file_lst,db_config* conf)
     
     
     error(220,"Opening %s for md check\n",dl->filename);
-#ifdef HAVE_MMAP
     if(dl->size > 0) {
-#endif
       if(!(fh=open(dl->filename,O_RDONLY))){
 	error(5,"do_md():open() for %s failed:%s\n",
 	      dl->filename,strerror(errno));
@@ -187,7 +185,6 @@ list* do_md(list* file_lst,db_config* conf)
 	continue;
       }
 
-#ifdef HAVE_MMAP
       size=lseek(fh,0,SEEK_END);
       if(dl->size!=size){
 	error(20,"File size has changed for %s while aide was running (%d->%d).\n",dl->filename,dl->size,size);
@@ -198,6 +195,7 @@ list* do_md(list* file_lst,db_config* conf)
 	}
       }
       
+#ifdef HAVE_MMAP
       buf = mmap(0, dl->size, PROT_READ, MAP_SHARED, fh, 0);
       if ( buf == MAP_FAILED ) {
 	error(5,"error mmap'ing %s\n", dl->filename);
@@ -222,18 +220,48 @@ list* do_md(list* file_lst,db_config* conf)
 	 'normal' read function.
 	 
       */
-      
-      for(counter = 0; counter + 16384 <= dl->size;counter += 16384){
+
+      /* IMPROVE
+	 I don't want to mmap the same file twice.
+	 This can cause trouble if you have an extremely large file
+	 But then again who wants to take an MD sum of a file
+	 that is >2GB. If someone has trouble with this I can
+	 fix it later on.*/
+	/* for(counter = 0; counter + 16384 <= dl->size;counter += 16384){*/
 	/* If the file is truncated after lseek */
 	/* Aide could cause SIGBUS and die */
 	/* An error message is displayed in this case */
+      md_write(mdh,(byte*)buf,dl->size);	
+#ifdef WITH_MHASH
+	for(i=0;i<MHASH_CRC32B;i++) {
+	  if (mhash_mdh[i*2+1]==1) {
+	    mhash (mhash_mdh[i*2], buf, dl->size);
+	  }
+	}
+#endif /* WITH_MHASH */
+	/* This is part of the old way of doing things.
+	  }
+      counter = dl->size - counter;
+      if (counter){
+	md_write(mdh,(byte*)buf,counter);
+#ifdef WITH_MHASH
+	for(i=0;i<MHASH_CRC32B;i++) {
+	  if (mhash_mdh[i*2+1]==1) {
+	    mhash (mhash_mdh[i*2], buf, counter);
+	  }
+	}
 #endif
+      }
+	*/
+      munmap(buf, dl->size);
+      conf->catch_mmap=0;
+#endif /* HAVE_MMAP */
 #ifndef HAVE_MMAP
+      /* We must go back to the beginning for read */
+      lseek(fh,0,SEEK_SET);
     /* Let's read */
 	do{
-	  /* fread arguments must be 1 and BUFSIZE not BUFSIZE and 1 */
-	  /* bread=fread(buf,1,BUFSIZE,fh); */
-	  bread=read(fh,buf,BUFSIZE);
+	  bread=read(fh,buf,READ_BLOCK_SIZE);
 	  
 	  md_write(mdh,(byte*)buf,bread);
 #ifdef WITH_MHASH
@@ -246,36 +274,10 @@ list* do_md(list* file_lst,db_config* conf)
 	}
 	while(bread!=0);
 #endif
-
-	md_write(mdh,(byte*)buf,16384);	
-#ifdef HAVE_MMAP
-#ifdef WITH_MHASH
-	for(i=0;i<MHASH_CRC32B;i++) {
-	  if (mhash_mdh[i*2+1]==1) {
-	    mhash (mhash_mdh[i*2], buf, 16384);
-	  }
-	}
-#endif
-      }
-      counter = dl->size - counter;
-      if (counter){
-	md_write(mdh,(byte*)buf,counter);
-#ifdef WITH_MHASH
-	for(i=0;i<MHASH_CRC32B;i++) {
-	  if (mhash_mdh[i*2+1]==1) {
-	    mhash (mhash_mdh[i*2], buf, counter);
-	  }
-	}
-#endif
-      }
-      munmap(buf, dl->size);
-      conf->catch_mmap=0;
-#endif
       if(close(fh)){
 	error(5,"do_md():close() for %s failed:%s\n",
 	      dl->filename,strerror(errno));
       }
-#ifdef HAVE_MMAP
     } else {
     dummywrite:
       md_write(mdh,(byte*)buf,0);
@@ -287,7 +289,6 @@ list* do_md(list* file_lst,db_config* conf)
 	} 
 #endif
     }
-#endif          
     md_final(mdh); /* Let's flush the buffers */
 
     if(dl->md5){
@@ -325,6 +326,13 @@ list* do_md(list* file_lst,db_config* conf)
   
   md_close(mdh);
 
+#ifndef HAVE_MMAP
+
+  free(buf);
+
+#endif
+
+
   return file_lst;
 }
 
