@@ -22,7 +22,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 
-#include "error.h"
+#include "report.h"
 #include "list.h"
 #include "aide.h"
 #include "be.h"
