@@ -18,6 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "aide.h"
 #include <assert.h>
 #include <stdlib.h>
 #include <string.h>
@@ -25,9 +26,10 @@
 #include <unistd.h>
 #include <limits.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <errno.h>
 #include <time.h>
-#include "error.h"
+#include "report.h"
 #include "config.h"
 #include "gnu_regex.h"
 #include "list.h"
@@ -62,6 +64,11 @@ char* strrxtok(char* rx)
       case '^':
       case '$':
       case '*':
+	/* FIXME: The '\\' character should be handled more gracefully. */
+	/* That is, if it is the only special character then */
+	/* The next character should be taken literally so */
+	/* that the search would be more efficient */
+      case '\\':
 	i=strlen(rx);
 	break;
       default:
@@ -433,7 +440,9 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   char* fullname=NULL;
   int e=0;
   int matchattr=attr;
+  #ifndef HAVE_READDIR_R
   long td=-1;
+  #endif
   int addok=RETOK;
 
   if(!(dirh=opendir(tree->path))){
@@ -448,19 +457,19 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
     malloc(sizeof(struct dirent)+_POSIX_PATH_MAX);
   
   for(rdres=readdir_r(dirh,entp,resp);
-      (rdres!=-1&&td!=telldir(dirh));
+      (rdres==0&&(*resp)!=NULL);
       rdres=readdir_r(dirh,entp,resp)){
   #else
   # ifdef HAVE_READDIR
   for(entp=readdir(dirh);
       (entp!=NULL&&td!=telldir(dirh));
       entp=readdir(dirh)){
+    td=telldir(dirh);
   # else
   #  error AIDE needs readdir or readdir_r
   # endif
   #endif
 
-    td=telldir(dirh);
     if(strncmp(entp->d_name,".",1)==0){
       if(strncmp(entp->d_name,".",strlen(entp->d_name))==0)
 	continue;
