@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999 Rami Lehti,Pablo Virolainen
- * $Header: /cvs-root-aide/aide/src/list.c,v 1.11 1999/11/25 09:25:27 pablo Exp $
+ * $Header: /cvs-root-aide/aide/src/list.c,v 1.12 2000/01/07 11:19:09 pablo Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +25,11 @@
  * limitations:
  * Only the head knows where the tail is
  * Every item knows where the head is
+ 
+ * And that is not true anymore. 
+ * Now list has header which knows head and tail.
+ * Every irem knows header.
+ 
  */
 
 /* list_append()
@@ -34,21 +39,30 @@
  * The second argument is the data to be added
  * Returns list head
  */
+
+
+/* 
+ * Some way to handle mallocs failure would be nice. Now it say abort().
+ */
+
 list* list_append(list* listp,void*data)
 {
   list* newitem=NULL;
   newitem=(list*)malloc(sizeof(list));
 
+  if (newitem==NULL) {
+    error(0,"Not enough memory to add a new item to list.\n");
+    abort();
+  }
+  
   if(listp==NULL){
     list_header* header=(list_header*)malloc(sizeof(list_header));
-    /*
-
+    
     if (header==NULL){
       error(0,"Not enough memory for list header allocation\n");
       abort();
     }
     
-    */
     newitem->data=data;
     newitem->header=header;
     newitem->next=NULL;
@@ -81,9 +95,14 @@ list* list_append(list* listp,void*data)
  * new_list_item()
  * create a new list item with data
  */
+
+/*
+
+obsolete
+
 list* new_list_item(void* data)
 {
-  /*
+
   list* item=NULL;
 
   item=(list*)malloc(sizeof(list));
@@ -92,13 +111,14 @@ list* new_list_item(void* data)
   item->head=item;
   item->tail=item;
   item->data=data;
-  */
   
   abort();
 
   return NULL;
 }
 
+*/
+
 /*
  * delete_list_item()
  * delete a item from list
@@ -106,7 +126,13 @@ list* new_list_item(void* data)
 
 list* list_delete_item(list* item){
   list* r;
-    
+
+
+  if (item==NULL) {
+    error(200,"Tried to remove from empthy list\n");
+    return item;
+  }
+  
   if (item->header->head==item->header->tail) {
     /*
      * Ollaan poistamassa listan ainoaa alkiota.
