@@ -29,7 +29,7 @@
 #define MAXHOSTNAMELEN 256
 #endif
 
-#include "error.h"
+#include "report.h"
 #include "db_config.h"
 #include "util.h"
 #include "aide.h"
